"""
ModelStatus class module.
"""
from __future__ import annotations

from digitalhub_core.entities._base.status import Status


class ModelStatus(Status):
    """
    Status class for model entities.
    """


class ModelStatusModel(ModelStatus):
    """
    Status class for model entities.
    """
